@@ -186,7 +186,7 @@ def assessment(output_root='./test_output/', read1=None,  cores=1, read2=None, a
     _alignment(output_root=output_root, read1=output_root + 'fastq/clean_read1.fq.gz', bowtie_index=bowtie_index, gtf=gtf, cores=cores )
 
   _genome_tracks(output_root=output_root, bam=output_root + 'sam/uniquemapped_sort.bam')
-  _render_template(output_root=output_root, type='assessment')
+  _render_template(output_root=output_root, type='assessment', is_server='False')
 
 def all(output_root='./test_output/', read1=None, bowtie_index=None,  gtf=None,  cores=1, read2=None, adapter1=None, adapter2=None, umi=None, tf_source=None, tf_filter_nodes=None, enhancer_source=None, enhancer_filter_nodes=None):
   logger.info('all--check installed software')
@@ -295,7 +295,6 @@ def _preprocess(output_root=os.getcwd()+'/tmp_output', read1=None,  cores=1, rea
   log_file.write( 'read1--'+os.path.basename(read1)+'\n' )
   log_file.write('read1_size--' + str(os.stat(read1).st_size / (1024 * 1024)) + 'Mb'+'\n')
 
-
   # 可选参数
   cur_cores = _get_cores(cores)
   cmd_list.extend(['--cores', str(cur_cores)])
@@ -309,10 +308,13 @@ def _preprocess(output_root=os.getcwd()+'/tmp_output', read1=None,  cores=1, rea
   if adapter1:
     _check_para('--adapter1', adapter1, str, required=True, output_root=output_root)
     cmd_list.extend(['--adapter1', adapter1])
+    log_file.write( 'adapter1--'+ adapter1 +'\n' )
+
 
   if adapter2:
     _check_para('--adapter2', adapter2, str, required=True, output_root=output_root)
     cmd_list.extend(['--adapter2', adapter2])
+    log_file.write( 'adapter2--'+ adapter2 +'\n' )
 
   # print( ' '.join(cmd_list) )
   log_file.write(_cur_time()+ 'preprocess start'+'\n')
@@ -322,7 +324,7 @@ def _preprocess(output_root=os.getcwd()+'/tmp_output', read1=None,  cores=1, rea
   os.system( ' '.join(['python', self_scripts + 'extract_preprocess.py', output_root]) )
 
   log_file.close()
-  logger.success('preprocess--Finished. Find the results in ' + output_root)
+  logger.success(_cur_time() + 'preprocess--Finished. Find the results in ' + output_root)
 
 def _alignment(read1=None, bowtie_index=None, gtf=None, output_root=None, cores=1, read2=None ):
   logger.info('alignment--check installed software')
@@ -332,7 +334,7 @@ def _alignment(read1=None, bowtie_index=None, gtf=None, output_root=None, cores=
   if not output_root.endswith('/'): output_root = output_root + '/'
   logger.info('alignment--construct output dir')
   _build_project_path(output_root)
-  log_file = open(output_root + 'tmp.log', 'w' )
+  log_file = open(output_root + 'tmp.log', 'a+' )
   cmd_list = ['bash', self_scripts + 'map1.bash']
   cmd_list.extend(['--output_root', output_root])
 
@@ -365,7 +367,7 @@ def _alignment(read1=None, bowtie_index=None, gtf=None, output_root=None, cores=
   cmd_list[1] = self_scripts + 'map2.bash'
   os.system( ' '.join(cmd_list) )
   log_file.close()
-  logger.success('alignment--Finished. Find the results in ' + output_root)
+  logger.success(_cur_time()+ 'alignment--Finished. Find the results in ' + output_root)
 
 def _genome_tracks(bam=None, output_root=None, cores=1):
   logger.info('genome_tracks--check installed software')
@@ -375,7 +377,7 @@ def _genome_tracks(bam=None, output_root=None, cores=1):
   if not output_root.endswith('/'): output_root = output_root + '/'
   logger.info('genome_tracks--construct output dir')
   _build_project_path(output_root)
-  log_file = open(output_root + 'tmp.log', 'w' )
+  log_file = open(output_root + 'tmp.log', 'a+' )
   cmd_list = ['bamCoverage', '--binSize', '1']
   _check_para('--bam', bam, str, isFile=True, required=True, output_root=output_root)
   cmd_list.extend(['--bam', bam])
@@ -396,7 +398,7 @@ def _genome_tracks(bam=None, output_root=None, cores=1):
   log_file.write(_cur_time()+ 'generate reverse genome track start\n')
   os.system( ' '.join(cmd_list_reverse) )
   log_file.close()
-  logger.success('genome_tracks--Finished. Find the results in ' + output_root)
+  logger.success(_cur_time()+'genome_tracks--Finished. Find the results in ' + output_root)
 
 def feature_assign(forward_bw=None, reverse_bw=None, gtf=None, output_root=None):
   logger.info('feature_assign--check installed software')
@@ -424,13 +426,15 @@ def feature_assign(forward_bw=None, reverse_bw=None, gtf=None, output_root=None)
 
   cmd_list.extend(['--output_root', output_root])
   log_file.write(_cur_time()+ 'feature assign start\n')
-  log_file.close()
+
   try:
     os.system( ' '.join(cmd_list) )
     logger.success('feature_assign--Finished. Find the results in ' + output_root)
   except:
     logger.error('feature_assign--Failed')
-  _render_template(output_root=output_root, type='quantification')
+  log_file.write(_cur_time()+ 'feature assign finished\n')
+  log_file.close()
+  _render_template(output_root=output_root, type='quantification', is_server='False')
 
 def pausing_sites(forward_bw=None, reverse_bw=None, output_root=None, cores=1):
   logger.info('pausing_sites--check installed software')
@@ -442,7 +446,7 @@ def pausing_sites(forward_bw=None, reverse_bw=None, output_root=None, cores=1):
   _build_project_path(output_root)
   log_file = open(output_root + 'tmp.log', 'w' )
 
-  cmd_list = ['python', self_scripts + 'pausing_sites.py']
+  cmd_list = ['python', self_scripts + 'pausing_sites_low_memory.py']
 
   _check_para('--forward_bw', forward_bw, str, isFile=True, required=True, output_root=output_root)
   cmd_list.extend(['--forward_bw', forward_bw])
@@ -465,7 +469,7 @@ def pausing_sites(forward_bw=None, reverse_bw=None, output_root=None, cores=1):
     logger.success('pausing_sites--Finished. Find the results in ' + output_root)
   except:
     logger.error('pausing_sites--Failed')
-  _render_template(output_root=output_root, type='pausing')
+  _render_template(output_root=output_root, type='pausing', is_server='False')
 
 def network_analysis(tf_source=None, tf_filter_nodes=None, enhancer_source=None, enhancer_filter_nodes=None, output_root=None ):
   logger.info('network_analysis--check installed software')
@@ -499,7 +503,7 @@ def network_analysis(tf_source=None, tf_filter_nodes=None, enhancer_source=None,
 
   os.system( ' '.join(cmd_list) )
   logger.success('network analysis--Finished. Find the results in ' + output_root)
-  _render_template(output_root=output_root, type='network')
+  _render_template(output_root=output_root, type='network', is_server='False')
 
 def genome_tracks_visualize(forward_bw=None, reverse_bw=None, region=None, gene=None, output_root=None, cores=1):
   logger.info('genome_tracks_visualize--check installed software')
@@ -520,7 +524,7 @@ def genome_tracks_visualize(forward_bw=None, reverse_bw=None, region=None, gene=
   # 生成 pyGenomeTrack ini文件
 
 
-def _render_template(type='server', output_root=None):
+def _render_template(type='server', output_root=None, is_server=None):
   # 每个步骤对应了输出文件， 用来丰富报表的数据
   # 考虑到 要和论文的内容对应上，所以不能按照 流程来生成报告
   # 把报告分成 1 基础信息 2 qc 3 转录级别评价 4 暂停因子和暂停位点 5 网络分析
@@ -532,7 +536,8 @@ def _render_template(type='server', output_root=None):
   if not output_root.endswith('/'): output_root = output_root + '/'
   _build_project_path(output_root)
   cmd_list.extend(['--output_root', output_root])
-
+  if is_server:
+    cmd_list.extend( ['--is_server', is_server])
   os.system( ' '.join(cmd_list) )
 
 
@@ -550,7 +555,7 @@ def main():
     'feature_assign': feature_assign,
     'pausing_sites': pausing_sites,
     'network_analysis': network_analysis,
-    # 'render_template': _render_template,
+    'render_template': _render_template,
     'server': server,
     'all': all
   })
